aboutsummaryrefslogtreecommitdiff
path: root/verif/conformance/test_select.py
diff options
context:
space:
mode:
Diffstat (limited to 'verif/conformance/test_select.py')
-rw-r--r--verif/conformance/test_select.py28
1 files changed, 26 insertions, 2 deletions
diff --git a/verif/conformance/test_select.py b/verif/conformance/test_select.py
index 59feae1..05f6db8 100644
--- a/verif/conformance/test_select.py
+++ b/verif/conformance/test_select.py
@@ -1,4 +1,4 @@
-# Copyright (c) 2021-2022, ARM Limited.
+# Copyright (c) 2021-2023, ARM Limited.
# SPDX-License-Identifier: Apache-2.0
"""Select generated tests."""
import argparse
@@ -464,6 +464,12 @@ class EqualOperator(Operator):
name = "equal"
+class ExpOperator(Operator):
+ """Test selector for the EXP operator."""
+
+ name = "exp"
+
+
class FloorOperator(Operator):
"""Test selector for the FLOOR operator."""
@@ -507,11 +513,17 @@ class IdentityOperator(Operator):
class IntDivOperator(Operator):
"""Test selector for the INTDIV."""
name = "intdiv"
+class LogOperator(Operator):
+ """Test selector for the LOG operator."""
+
+ name = "log"
+
+
class LogicalAndOperator(Operator):
"""Test selector for the LOGICAL_AND operator."""
@@ -600,6 +612,12 @@ class PowOperator(Operator):
name = "pow"
+class ReciprocalOperator(Operator):
+ """Test selector for the RECIPROCAL operator."""
+
+ name = "reciprocal"
+
+
class ReduceAllOperator(Operator):
"""Test selector for the REDUCE_ALL operator."""
@@ -678,6 +696,12 @@ class ReverseOperator(Operator):
param_names = ["shape", "type", "axis"]
+class RsqrtOperator(Operator):
+ """Test selector for the RSQRT operator."""
+
+ name = "rsqrt"
+
+
class ScatterOperator(Operator):
"""Test selector for the SCATTER operator."""
@@ -507,11 +513,17 @@ class IdentityOperator(Operator):
class IntDivOperator(Operator):
- """Test selector for the INTDIV."""
+ """Test selector for the INTDIV operator."""
name = "intdiv"